/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.integration.animation_motion;

import java.util.Map;
import java.util.Map.Entry;
import org.osgi.framework.BundleContext;
import org.robokind.api.animation.utils.AnimationEditListener;
import org.robokind.api.common.position.NormalizedDouble;
import org.robokind.api.motion.Robot;
import org.robokind.api.motion.Joint;
import org.robokind.api.motion.utils.PositionTargetFrameSource;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class AnimationEditFrameSource extends PositionTargetFrameSource implements AnimationEditListener{

    public AnimationEditFrameSource(BundleContext context, Robot.Id robotId){
        super(context, robotId, 0.001, null);
        setStopOnGoal(true);
    }
    
    @Override
    public void handlePositions(long x, Map<Integer, Double> positions) {
        Robot.RobotPositionMap posMap = 
                new Robot.RobotPositionHashMap(positions.size());
        for(Entry<Integer,Double> e : positions.entrySet()){
            Integer id = e.getKey();
            Double rawPos = e.getValue();
            if(id == null || rawPos == null){
                continue;
            }else if(!NormalizedDouble.isValid(rawPos)){
                continue;
            }
            NormalizedDouble val = new NormalizedDouble(rawPos);
            Joint.Id jId = new Joint.Id(id);
            Robot.JointId djId = 
                    new Robot.JointId(getRobotId(), jId);
            posMap.put(djId, val);
        }
        this.putPositions(posMap);
    }    
}
